[−][src]Derive Macro concordium_std::Serialize
#[derive(Serialize)]
{
// Attributes available to this derive:
#[concordium]
}A helper macro to derive both the Serial and Deserial traits.
[derive(Serialize)] is equivalent to [derive(Serial,Deserial)], see
documentation of the latter two for details and options.