pub enum Address {
Account(AccountAddress),
Contract(ContractAddress),
}Expand description
Either an address of an account, or contract.
Variants
Account(AccountAddress)
Contract(ContractAddress)
Implementations
Sourceimpl Address
impl Address
pub fn matches_account(&self, acc: &AccountAddress) -> bool
pub fn matches_contract(&self, cnt: &ContractAddress) -> bool
Sourcepub fn is_account(&self) -> bool
pub fn is_account(&self) -> bool
Return true if and only if the address is an account address.
Sourcepub fn is_contract(&self) -> bool
pub fn is_contract(&self) -> bool
Return true if and only if the address is a contract address.