Enum concordium_std::SeekFrom [−][src]
This is the equivalent to the
SeekFrom type from
the rust standard library, but reproduced here to avoid dependency on
std::io.
Variants
Start(u64)End(i64)Current(i64)This is the equivalent to the
SeekFrom type from
the rust standard library, but reproduced here to avoid dependency on
std::io.
Start(u64)End(i64)Current(i64)impl RefUnwindSafe for SeekFromimpl Send for SeekFromimpl Sync for SeekFromimpl Unpin for SeekFromimpl UnwindSafe for SeekFrom