write_output

Function write_output 

pub unsafe extern "C" fn write_output(
    start: *const u8,
    length: u32,
    offset: u32,
) -> u32
Write to the return value of the contract. The parameters are

  • start the pointer to the location in memory where the data resides
  • length the size of data (in bytes)
  • offset where in the return value to write the data

The return value indicates how many bytes were written.