Enum concordium_std::schema::Fields [−][src]
Schema for the fields of a struct or some enum variant.
Variants
Named fields, e.g., struct Foo {x: u64, y: u32}.
Unnamed fields, e.g., struct Foo(u64, u32)
No fields. Note that this is distinct from an empty set of named or
unnamed fields. That is, in Rust there is a (albeit trivial) difference
between struct Foo {}, struct Foo, and struct Foo(), all of which
are valid, but will have different representations.