Struct concordium_std::schema::ContractV0
source · [−]pub struct ContractV0 {
pub state: Option<Type>,
pub init: Option<Type>,
pub receive: BTreeMap<String, Type>,
}Expand description
Describes all the schemas of a V0 smart contract. The Default instance produces an empty schema.
Fields
state: Option<Type>init: Option<Type>receive: BTreeMap<String, Type>Trait Implementations
sourceimpl Clone for ContractV0
impl Clone for ContractV0
sourcefn clone(&self) -> ContractV0
fn clone(&self) -> ContractV0
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ContractV0
impl Debug for ContractV0
sourceimpl Default for ContractV0
impl Default for ContractV0
sourcefn default() -> ContractV0
fn default() -> ContractV0
Returns the “default value” for a type. Read more
sourceimpl Deserial for ContractV0
impl Deserial for ContractV0
sourcefn deserial<R>(source: &mut R) -> Result<ContractV0, ParseError> where
R: Read,
fn deserial<R>(source: &mut R) -> Result<ContractV0, ParseError> where
R: Read,
Attempt to read a structure from a given source, failing if an error occurs during deserialization or reading. Read more