Struct concordium_std::schema::ContractV1
source · [−]Expand description
Describes all the schemas of a V1 smart contract. The Default instance produces an empty schema.
Fields
init: Option<Function>receive: BTreeMap<String, Function>Trait Implementations
sourceimpl Clone for ContractV1
impl Clone for ContractV1
sourcefn clone(&self) -> ContractV1
fn clone(&self) -> ContractV1
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ContractV1
impl Debug for ContractV1
sourceimpl Default for ContractV1
impl Default for ContractV1
sourcefn default() -> ContractV1
fn default() -> ContractV1
Returns the “default value” for a type. Read more
sourceimpl Deserial for ContractV1
impl Deserial for ContractV1
sourcefn deserial<R>(source: &mut R) -> Result<ContractV1, ParseError> where
R: Read,
fn deserial<R>(source: &mut R) -> Result<ContractV1, ParseError> where
R: Read,
Attempt to read a structure from a given source, failing if an error occurs during deserialization or reading. Read more