pub struct FunctionV2 {
    pub parameter: Option<Type>,
    pub return_value: Option<Type>,
    pub error: Option<Type>,
}
Describes the schema of an init or a receive function for V1 contracts with V3 schemas. Differs from FunctionV1 in that a schema for the error can be included.

Fields

parameter: Option<Type>return_value: Option<Type>error: Option<Type>

Implementations

source

impl FunctionV2

source

pub fn parameter(&self) -> Option<&Type>

Extract the parameter schema if it exists.

source

pub fn return_value(&self) -> Option<&Type>

Extract the return value schema if it exists.

source

pub fn error(&self) -> Option<&Type>

Extract the error schema if it exists.