pub struct AccountBalance {
    pub total: Amount,
    pub staked: Amount,
    pub locked: Amount,
}
The current public balances of an account.

Fields

total: Amount

The total balance of the account. Note that part of this balance might be staked and/or locked in scheduled transfers.

staked: Amount

The current staked amount of the account. This amount is used for staking.

locked: Amount

The current amount locked in releases that resulted from transfers with schedule. A locked amount can still be used for staking.

Implementations

Construct a new account balance, ensuring that both the staked amount and the locked amount is smaller than or equal to the total balance.

The current available balance of the account. This is the amount an account currently have available for transfering and is not staked or locked in releases by scheduled transfers.