Struct concordium_std::Action [−][src]
#[must_use]pub struct Action { /* fields omitted */ }
Actions that can be produced at the end of a contract execution. This
type is deliberately not cloneable so that we can enforce that
and_then and or_else can only be used when more than one event is
created.
This type is marked as must_use since functions that produce
values of the type are effectful.
Implementations