Struct concordium_std::ChainMetadata
source · pub struct ChainMetadata {
pub slot_time: Timestamp,
}Expand description
Chain metadata accessible to both receive and init methods.
Fields
slot_time: TimestampTrait Implementations
sourceimpl Clone for ChainMetadata
impl Clone for ChainMetadata
sourcefn clone(&self) -> ChainMetadata
fn clone(&self) -> ChainMetadata
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ChainMetadata
impl Debug for ChainMetadata
sourceimpl Deserial for ChainMetadata
impl Deserial for ChainMetadata
sourcefn deserial<R>(source: &mut R) -> Result<ChainMetadata, ParseError>where
R: Read,
fn deserial<R>(source: &mut R) -> Result<ChainMetadata, ParseError>where
R: Read,
Attempt to read a structure from a given source, failing if an error
occurs during deserialization or reading. Read more