Struct concordium_std::ContractAddress [−][src]
Address of a contract.
Fields
index: u64subindex: u64Trait Implementations
Attempt to read a structure from a given source, failing if an error occurs during deserialization or reading. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more