pub struct ContractName<'a>(_);
A contract name. Expected format: “init_<contract_name>”.

Implementations

Create a new ContractName and check the format. Expected format: “init_<contract_name>”.

Create a new ContractName without checking the format. Expected format: “init_<contract_name>”. If this precondition is not satisfied then the behaviour of any methods on this type is unspecified, and may include panics.

Get contract name used on chain: “init_<contract_name>”.

Extract the contract name by removing the “init_” prefix.

Check whether the given string is a valid contract initialization function name. This is the case if and only if

  • the string is no more than constants::MAX_FUNC_NAME_SIZE bytes
  • the string starts with init_
  • the string does not contain a .
  • all characters are ascii alphanumeric or punctuation characters.