pub struct EntrypointName<'a>(/* private fields */);Expand description
An entrypoint name (borrowed version). Expected format: “<func_name>” where the name of the function consists solely of ASCII alphanumeric or punctuation characters.
Implementations
Sourceimpl<'a> EntrypointName<'a>
impl<'a> EntrypointName<'a>
Sourcepub fn new(name: &'a str) -> Result<EntrypointName<'a>, NewReceiveNameError>
pub fn new(name: &'a str) -> Result<EntrypointName<'a>, NewReceiveNameError>
Create a new name and check the format. See is_valid_entrypoint_name for the expected format.
Sourcepub fn to_owned(&self) -> OwnedEntrypointName
pub fn to_owned(&self) -> OwnedEntrypointName
Convert a EntrypointName to its owned counterpart. This is an
expensive operation that requires memory allocation.
Sourcepub const fn new_unchecked(name: &'a str) -> EntrypointName<'a>
pub const fn new_unchecked(name: &'a str) -> EntrypointName<'a>
Create a new name. This does not check the format and is therefore unsafe. It is provided for convenience since sometimes it is statically clear that the format is satisfied.