Struct concordium_std::HashKeccak256
source · [−]Expand description
Keccak digest with 256 bits (32 bytes).
Tuple Fields
0: [u8; 32]Trait Implementations
sourceimpl Clone for HashKeccak256
impl Clone for HashKeccak256
sourcefn clone(&self) -> HashKeccak256
fn clone(&self) -> HashKeccak256
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for HashKeccak256
impl Debug for HashKeccak256
sourceimpl Deserial for HashKeccak256
impl Deserial for HashKeccak256
sourceimpl Ord for HashKeccak256
impl Ord for HashKeccak256
sourceimpl PartialEq<HashKeccak256> for HashKeccak256
impl PartialEq<HashKeccak256> for HashKeccak256
sourcefn eq(&self, other: &HashKeccak256) -> bool
fn eq(&self, other: &HashKeccak256) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &HashKeccak256) -> bool
fn ne(&self, other: &HashKeccak256) -> bool
This method tests for !=.
sourceimpl PartialOrd<HashKeccak256> for HashKeccak256
impl PartialOrd<HashKeccak256> for HashKeccak256
sourcefn partial_cmp(&self, other: &HashKeccak256) -> Option<Ordering>
fn partial_cmp(&self, other: &HashKeccak256) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl SchemaType for HashKeccak256
impl SchemaType for HashKeccak256
sourceimpl Serial for HashKeccak256
impl Serial for HashKeccak256
impl Copy for HashKeccak256
impl Eq for HashKeccak256
impl StructuralEq for HashKeccak256
impl StructuralPartialEq for HashKeccak256