Struct concordium_std::PublicKeyEcdsaSecp256k1
source · [−]Expand description
Public key for ECDSA over Secp256k1. Must be 33 bytes long.
Tuple Fields
0: [u8; 33]Trait Implementations
sourceimpl Clone for PublicKeyEcdsaSecp256k1
impl Clone for PublicKeyEcdsaSecp256k1
sourcefn clone(&self) -> PublicKeyEcdsaSecp256k1
fn clone(&self) -> PublicKeyEcdsaSecp256k1
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for PublicKeyEcdsaSecp256k1
impl Debug for PublicKeyEcdsaSecp256k1
sourceimpl Deserial for PublicKeyEcdsaSecp256k1
impl Deserial for PublicKeyEcdsaSecp256k1
sourceimpl Ord for PublicKeyEcdsaSecp256k1
impl Ord for PublicKeyEcdsaSecp256k1
sourceimpl PartialEq<PublicKeyEcdsaSecp256k1> for PublicKeyEcdsaSecp256k1
impl PartialEq<PublicKeyEcdsaSecp256k1> for PublicKeyEcdsaSecp256k1
sourcefn eq(&self, other: &PublicKeyEcdsaSecp256k1) -> bool
fn eq(&self, other: &PublicKeyEcdsaSecp256k1) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &PublicKeyEcdsaSecp256k1) -> bool
fn ne(&self, other: &PublicKeyEcdsaSecp256k1) -> bool
This method tests for !=.
sourceimpl PartialOrd<PublicKeyEcdsaSecp256k1> for PublicKeyEcdsaSecp256k1
impl PartialOrd<PublicKeyEcdsaSecp256k1> for PublicKeyEcdsaSecp256k1
sourcefn partial_cmp(&self, other: &PublicKeyEcdsaSecp256k1) -> Option<Ordering>
fn partial_cmp(&self, other: &PublicKeyEcdsaSecp256k1) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl SchemaType for PublicKeyEcdsaSecp256k1
impl SchemaType for PublicKeyEcdsaSecp256k1
sourceimpl Serial for PublicKeyEcdsaSecp256k1
impl Serial for PublicKeyEcdsaSecp256k1
impl Copy for PublicKeyEcdsaSecp256k1
impl Eq for PublicKeyEcdsaSecp256k1
impl StructuralEq for PublicKeyEcdsaSecp256k1
impl StructuralPartialEq for PublicKeyEcdsaSecp256k1