Struct concordium_std::ReceiveName
source · pub struct ReceiveName<'a>(/* private fields */);Expand description
A receive name. Expected format: “<contract_name>.<func_name>”.
Implementations
sourceimpl<'a> ReceiveName<'a>
impl<'a> ReceiveName<'a>
sourcepub fn new(name: &'a str) -> Result<ReceiveName<'a>, NewReceiveNameError>
pub fn new(name: &'a str) -> Result<ReceiveName<'a>, NewReceiveNameError>
Create a new ReceiveName and check the format. Expected format: “<contract_name>.<func_name>”.
sourcepub fn new_unchecked(name: &'a str) -> ReceiveName<'a>
pub fn new_unchecked(name: &'a str) -> ReceiveName<'a>
Create a new ReceiveName without checking the format. Expected format: “<contract_name>.<func_name>”.
sourcepub fn get_chain_name(self) -> &'a str
pub fn get_chain_name(self) -> &'a str
Get receive name used on chain: “<contract_name>.<func_name>”.
sourcepub fn to_owned(self) -> OwnedReceiveName
pub fn to_owned(self) -> OwnedReceiveName
Convert a ReceiveName to its owned counterpart. This is an expensive
operation that requires memory allocation.
sourcepub fn contract_name(self) -> &'a str
pub fn contract_name(self) -> &'a str
Extract the contract name by splitting at the first dot.
sourcepub fn entrypoint_name(self) -> EntrypointName<'a>
pub fn entrypoint_name(self) -> EntrypointName<'a>
Extract the entrypoint name by splitting at the first dot.
sourcepub fn is_valid_receive_name(name: &str) -> Result<(), NewReceiveNameError>
pub fn is_valid_receive_name(name: &str) -> Result<(), NewReceiveNameError>
Check whether the given string is a valid contract receive function name. This is the case if and only if
- the string is no more than constants::MAX_FUNC_NAME_SIZE bytes
- the string contains a
. - all characters are ascii alphanumeric or punctuation characters.