Struct concordium_std::SignatureEd25519
source · [−]Expand description
Signature for a Ed25519 message. Must be 64 bytes long.
Tuple Fields
0: [u8; 64]Trait Implementations
sourceimpl Clone for SignatureEd25519
impl Clone for SignatureEd25519
sourcefn clone(&self) -> SignatureEd25519
fn clone(&self) -> SignatureEd25519
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for SignatureEd25519
impl Debug for SignatureEd25519
sourceimpl Deserial for SignatureEd25519
impl Deserial for SignatureEd25519
sourceimpl Ord for SignatureEd25519
impl Ord for SignatureEd25519
sourceimpl PartialEq<SignatureEd25519> for SignatureEd25519
impl PartialEq<SignatureEd25519> for SignatureEd25519
sourcefn eq(&self, other: &SignatureEd25519) -> bool
fn eq(&self, other: &SignatureEd25519) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &SignatureEd25519) -> bool
fn ne(&self, other: &SignatureEd25519) -> bool
This method tests for !=.
sourceimpl PartialOrd<SignatureEd25519> for SignatureEd25519
impl PartialOrd<SignatureEd25519> for SignatureEd25519
sourcefn partial_cmp(&self, other: &SignatureEd25519) -> Option<Ordering>
fn partial_cmp(&self, other: &SignatureEd25519) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl SchemaType for SignatureEd25519
impl SchemaType for SignatureEd25519
sourceimpl Serial for SignatureEd25519
impl Serial for SignatureEd25519
impl Copy for SignatureEd25519
impl Eq for SignatureEd25519
impl StructuralEq for SignatureEd25519
impl StructuralPartialEq for SignatureEd25519