pub struct VacantEntry<'a, K, V, S> { /* private fields */ }
A view into a vacant entry in a StateMap. It is part of the Entry enum.

Differs from VacantEntryRaw in that this automatically handles serialization.

Implementations

Get a reference to the VacantEntry’s key.

Take ownership of the key.

Sets the value of the entry with the VacantEntry’s key.