Struct concordium_std::VacantEntryRaw
source · [−]pub struct VacantEntryRaw<S> { /* private fields */ }Expand description
A view into a vacant entry in a HasStateApi type.
It is part of the EntryRaw enum.
Differs from VacantEntry in that this has access to the raw bytes stored
in the state via a HasStateEntry type.
Implementations
sourceimpl<StateApi: HasStateApi> VacantEntryRaw<StateApi>
impl<StateApi: HasStateApi> VacantEntryRaw<StateApi>
sourcepub fn key(&self) -> &[u8]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
pub fn key(&self) -> &[u8]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
Gets a reference to the key that would be used when inserting a value
through the VacantEntryRaw.
sourcepub fn insert_raw(self, value: &[u8]) -> Result<StateApi::EntryType, StateError>
pub fn insert_raw(self, value: &[u8]) -> Result<StateApi::EntryType, StateError>
Sets the value of the entry with the VacantEntryRaw’s key.
sourcepub fn insert<V: Serial>(
self,
value: &V
) -> Result<StateApi::EntryType, StateError>
pub fn insert<V: Serial>(
self,
value: &V
) -> Result<StateApi::EntryType, StateError>
Sets the value of the entry with the VacantEntryRaw’s key.
This differs from
insert_raw in that it automatically serializes
the provided value. insert should be preferred
for values that can be directly converted to byte arrays, e.g., any
value that implements AsRef<[u8]>.