Enum concordium_std::test_infrastructure::ActionsTree [−][src]
pub enum ActionsTree {
Accept,
SimpleTransfer {
to: AccountAddress,
amount: Amount,
},
Send {
to: ContractAddress,
receive_name: OwnedReceiveName,
amount: Amount,
parameter: Vec<u8>,
},
AndThen {
left: Box<ActionsTree>,
right: Box<ActionsTree>,
},
OrElse {
left: Box<ActionsTree>,
right: Box<ActionsTree>,
},
}Expand description
An actions tree, used to provide a simpler presentation for testing.
Variants
Show fields
Fields of SimpleTransfer
to: AccountAddressamount: AmountShow fields
Fields of Send
Show fields
Fields of AndThen
left: Box<ActionsTree>right: Box<ActionsTree>Show fields
Fields of OrElse
left: Box<ActionsTree>right: Box<ActionsTree>Trait Implementations
impl Debug for ActionsTree[src]
impl Debug for ActionsTree[src]impl HasActions for ActionsTree[src]
impl HasActions for ActionsTree[src]fn simple_transfer(acc: &AccountAddress, amount: Amount) -> Self[src]
fn simple_transfer(acc: &AccountAddress, amount: Amount) -> Self[src]Send a given amount to an account.
fn send_raw(
ca: &ContractAddress,
receive_name: ReceiveName<'_>,
amount: Amount,
parameter: &[u8]
) -> Self[src]
fn send_raw(
ca: &ContractAddress,
receive_name: ReceiveName<'_>,
amount: Amount,
parameter: &[u8]
) -> Self[src]Send a message to a contract.
impl PartialEq<ActionsTree> for ActionsTree[src]
impl PartialEq<ActionsTree> for ActionsTree[src]fn eq(&self, other: &ActionsTree) -> bool[src]
fn eq(&self, other: &ActionsTree) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(&self, other: &ActionsTree) -> bool[src]
fn ne(&self, other: &ActionsTree) -> bool[src]This method tests for !=.