Struct concordium_std::test_infrastructure::ContractStateTest [−][src]
pub struct ContractStateTest<T> {
pub cursor: Cursor<T>,
}Expand description
Contract state for testing, mimicking the operations the scheduler allows, including the limit on the size of the maximum size of the contract state.
Fields
cursor: Cursor<T>Trait Implementations
impl<T: AsMut<Vec<u8>> + AsMut<[u8]> + AsRef<[u8]>> HasContractState<ContractStateError> for ContractStateTest<T>[src]
impl<T: AsMut<Vec<u8>> + AsMut<[u8]> + AsRef<[u8]>> HasContractState<ContractStateError> for ContractStateTest<T>[src]type ContractStateData = T
fn open(data: Self::ContractStateData) -> Self[src]
fn open(data: Self::ContractStateData) -> Self[src]Open the contract state. Only one instance can be opened at the same time. Read more
impl<T: AsRef<[u8]>> Read for ContractStateTest<T>[src]
impl<T: AsRef<[u8]>> Read for ContractStateTest<T>[src]fn read(&mut self, buf: &mut [u8]) -> ParseResult<usize>[src]
fn read(&mut self, buf: &mut [u8]) -> ParseResult<usize>[src]Read a number of bytes into the provided buffer. The returned value is
Ok(n) if a read was successful, and n bytes were read (n could be
0). Read more
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), ParseError>[src]
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), ParseError>[src]Read exactly the required number of bytes. If not enough bytes could be
read the function returns Err(_), and the contents of the given buffer
is unspecified. Read more
fn read_u64(&mut self) -> Result<u64, ParseError>[src]
fn read_u64(&mut self) -> Result<u64, ParseError>[src]Read a u64 in little-endian format.
fn read_u32(&mut self) -> Result<u32, ParseError>[src]
fn read_u32(&mut self) -> Result<u32, ParseError>[src]Read a u32 in little-endian format.
fn read_u16(&mut self) -> Result<u16, ParseError>[src]
fn read_u16(&mut self) -> Result<u16, ParseError>[src]Read a u16 in little-endian format.
fn read_u8(&mut self) -> Result<u8, ParseError>[src]
fn read_u8(&mut self) -> Result<u8, ParseError>[src]Read a u8.
fn read_i64(&mut self) -> Result<i64, ParseError>[src]
fn read_i64(&mut self) -> Result<i64, ParseError>[src]Read a i64 in little-endian format.
fn read_i32(&mut self) -> Result<i32, ParseError>[src]
fn read_i32(&mut self) -> Result<i32, ParseError>[src]Read a i32 in little-endian format.
fn read_i16(&mut self) -> Result<i16, ParseError>[src]
fn read_i16(&mut self) -> Result<i16, ParseError>[src]Read a i16 in little-endian format.
fn read_i8(&mut self) -> Result<i8, ParseError>[src]
fn read_i8(&mut self) -> Result<i8, ParseError>[src]Read a i32 in little-endian format.
impl<T: AsMut<Vec<u8>>> Write for ContractStateTest<T>[src]
impl<T: AsMut<Vec<u8>>> Write for ContractStateTest<T>[src]type Err = ContractStateError
fn write(&mut self, buf: &[u8]) -> Result<usize, Self::Err>[src]
fn write(&mut self, buf: &[u8]) -> Result<usize, Self::Err>[src]Try to write the given buffer into the output stream. If writes are successful returns the number of bytes written. Read more