Struct concordium_std::test_infrastructure::LogRecorder [−][src]
A logger that simply accumulates all the logged items to be inspected at the end of execution.
Fields
logs: Vec<Vec<u8>>A logger that simply accumulates all the logged items to be inspected at the end of execution.
logs: Vec<Vec<u8>>impl RefUnwindSafe for LogRecorderimpl Send for LogRecorderimpl Sync for LogRecorderimpl Unpin for LogRecorderimpl UnwindSafe for LogRecorder