Struct concordium_std::test_infrastructure::TestChainMeta
source · pub struct TestChainMeta { /* private fields */ }👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
Placeholder for the context chain meta data.
All the fields are optionally set and the getting an unset field will result
in test failing.
For most cases it is used as part of either
TestInitContext or
TestReceiveContext.
Use only in unit tests!
Defaults to having all of the fields unset
Implementations
sourceimpl TestChainMeta
impl TestChainMeta
sourcepub fn empty() -> Self
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
pub fn empty() -> Self
Create an TestChainMeta where every field is unset, and getting any of
the fields will result in fail!.
sourcepub fn set_slot_time(&mut self, value: SlotTime) -> &mut Self
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
pub fn set_slot_time(&mut self, value: SlotTime) -> &mut Self
Set the block slot time