Struct concordium_std::test_infrastructure::TestLogger
source · [−]Expand description
A logger that simply accumulates all the logged items to be inspected at the end of execution.
Fields
logs: Vec<Vec<u8>>Trait Implementations