Struct concordium_std::test_infrastructure::TestPolicy
source · pub struct TestPolicy { /* private fields */ }Expand description
Policy type used by init and receive contexts for testing.
This type should not be used directly, but rather through
its HasPolicy interface.