pub trait Deletable {
fn delete(self);
}
A type that can be deleted from the state.
For simple types, such as u8 and String, the delete methods is a
no-op. But for StateBox, StateMap,
and StateSet, delete makes sure to the delete all
the necessary data from the state.
Delete all items that this type owns in the state.