ExpectNoneReport

Trait ExpectNoneReport 

pub trait ExpectNoneReport {
    // Required method
    fn expect_none_report(self, msg: &str);
}
Analogue of the expect_none methods on Option, but useful in a Wasm setting.

Required Methods

fn expect_none_report(self, msg: &str)

Like the default expect_none_report on, e.g., Option, but calling fail with the given message, instead of panic.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A: Debug> ExpectNoneReport for Option<A>

Implementors