ExpectReport

Trait ExpectReport 

pub trait ExpectReport {
    type Unwrap;

    // Required method
    fn expect_report(self, msg: &str) -> Self::Unwrap;
}
Analogue of the expect methods on types such as Option, but useful in a Wasm setting.

Required Associated Types

Required Methods

fn expect_report(self, msg: &str) -> Self::Unwrap

Like the default expect on, e.g., Result, but calling fail with the given message, instead of panic.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A, E: Debug> ExpectReport for Result<A, E>

Source

type Unwrap = A

Source

fn expect_report(self, msg: &str) -> Self::Unwrap

Source

impl<A> ExpectReport for Option<A>

Source

type Unwrap = A

Source

fn expect_report(self, msg: &str) -> Self::Unwrap

Implementors