Trait concordium_std::Serialize [−][src]
The Serialize trait provides a means of writing structures into byte-sinks
(Write) or reading structures from byte sources (Read).
Can be derived using #[derive(Serialized)] for most cases.
Implementors
impl<A> Serialize for A where
A: Deserial + Serial, [src]
A: Deserial + Serial,
Generic instance deriving Serialize for any type that implements both Serial and Deserial.