pub unsafe extern "C" fn write_output(
start: *const u8,
length: u32,
offset: u32,
) -> u32Expand description
Write to the return value of the contract. The parameters are
startthe pointer to the location in memory where the data resideslengththe size of data (in bytes)offsetwhere in the return value to write the data
The return value indicates how many bytes were written.