Struct concordium_std::AccountBalance
source · Expand description
The current public balances of an account.
Fields
total: AmountThe total balance of the account. Note that part of this balance might be staked and/or locked in scheduled transfers.
staked: AmountThe current staked amount of the account. This amount is used for staking.
locked: AmountThe current amount locked in releases that resulted from transfers with schedule. A locked amount can still be used for staking.
Implementations