Struct concordium_std::ContractAddress [−][src]
Address of a contract.
Fields
index: u64subindex: u64Trait Implementations
impl Clone for ContractAddress[src]
impl Clone for ContractAddress[src]pub fn clone(&self) -> ContractAddress[src]
pub fn clone(&self) -> ContractAddress[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for ContractAddress[src]
impl Debug for ContractAddress[src]impl Deserial for ContractAddress[src]
impl Deserial for ContractAddress[src]pub fn deserial<R>(source: &mut R) -> Result<ContractAddress, ParseError> where
R: Read, [src]
pub fn deserial<R>(source: &mut R) -> Result<ContractAddress, ParseError> where
R: Read, [src]Attempt to read a structure from a given source, failing if an error occurs during deserialization or reading. Read more
impl PartialEq<ContractAddress> for ContractAddress[src]
impl PartialEq<ContractAddress> for ContractAddress[src]pub fn eq(&self, other: &ContractAddress) -> bool[src]
pub fn eq(&self, other: &ContractAddress) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
pub fn ne(&self, other: &ContractAddress) -> bool[src]
pub fn ne(&self, other: &ContractAddress) -> bool[src]This method tests for !=.
impl SchemaType for ContractAddress[src]
impl SchemaType for ContractAddress[src]impl Serial for ContractAddress[src]
impl Serial for ContractAddress[src]impl Copy for ContractAddress[src]
impl Eq for ContractAddress[src]
impl StructuralEq for ContractAddress[src]
impl StructuralPartialEq for ContractAddress[src]