Struct concordium_std::ContractName
source · [−]pub struct ContractName<'a>(_);Expand description
A contract name. Expected format: “init_<contract_name>”.
Implementations
sourceimpl<'a> ContractName<'a>
impl<'a> ContractName<'a>
sourcepub fn new(name: &'a str) -> Result<ContractName<'a>, NewContractNameError>
pub fn new(name: &'a str) -> Result<ContractName<'a>, NewContractNameError>
Create a new ContractName and check the format. Expected format: “init_<contract_name>”.
sourcepub fn new_unchecked(name: &'a str) -> ContractName<'a>
pub fn new_unchecked(name: &'a str) -> ContractName<'a>
Create a new ContractName without checking the format. Expected format: “init_<contract_name>”. If this precondition is not satisfied then the behaviour of any methods on this type is unspecified, and may include panics.
sourcepub fn get_chain_name(self) -> &'a str
pub fn get_chain_name(self) -> &'a str
Get contract name used on chain: “init_<contract_name>”.
sourcepub fn contract_name(self) -> &'a str
pub fn contract_name(self) -> &'a str
Extract the contract name by removing the “init_” prefix.
sourcepub fn is_valid_contract_name(name: &str) -> Result<(), NewContractNameError>
pub fn is_valid_contract_name(name: &str) -> Result<(), NewContractNameError>
Check whether the given string is a valid contract initialization function name. This is the case if and only if
- the string is no more than constants::MAX_FUNC_NAME_SIZE bytes
- the string starts with
init_ - the string does not contain a
. - all characters are ascii alphanumeric or punctuation characters.