pub struct ReceiveName<'a>(_);
A receive name. Expected format: “<contract_name>.<func_name>”.

Implementations

Create a new ReceiveName and check the format. Expected format: “<contract_name>.<func_name>”.

Create a new ReceiveName without checking the format. Expected format: “<contract_name>.<func_name>”.

Get receive name used on chain: “<contract_name>.<func_name>”.

Convert a ReceiveName to its owned counterpart. This is an expensive operation that requires memory allocation.

Extract the contract name by splitting at the first dot.

Extract the entrypoint name by splitting at the first dot.

Check whether the given string is a valid contract receive function name. This is the case if and only if

  • the string is no more than constants::MAX_FUNC_NAME_SIZE bytes
  • the string contains a .
  • all characters are ascii alphanumeric or punctuation characters.