pub enum TestStateError {
Overflow,
Write,
Offset,
Default,
EntryDeleted,
}👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
An error that is raised when operating with Seek, Write, Read, or
HasStateEntry trait methods of the TestStateApi type.
Variants
Overflow
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
The computation of the new offset would result in an overflow.
Write
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
An error occurred when writing to the contract state.
Offset
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
The new offset would be out of bounds of the state.
Default
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
Some other error occurred.
EntryDeleted
👎Deprecated since 8.1.0: Deprecated in favor of concordium-smart-contract-testing.
The entry has been deleted (via delete_prefix).