pub struct TestCryptoPrimitives { /* private fields */ }
A HasCryptoPrimitives implementation used for unit testing smart contracts.

You can test smart contracts that use the cryptographic primitives in two different ways:

  1. By setting up mock responses for the functions you need, for example with the setup_hash_sha_256_mock method.
  2. Or, by using the actual implementations. For this, you need to enable the “crypto-primitives” feature.

Implementations

Create a new TestCryptoPrimitives, for which no mocks has been set up.

Set up a mock for verify_ed25519_signature.

This is not available if the “crypto-primitives” feature is enabled. For more information on why, see the documentation of TestCryptoPrimitives.

Set up a mock for verify_ecdsa_secp256k1_signature.

This is not available if the “crypto-primitives” feature is enabled. For more information on why, see the documentation of TestCryptoPrimitives.

Set up a mock for hash_sha2_256.

This is not available if the “crypto-primitives” feature is enabled. For more information on why, see the documentation of TestCryptoPrimitives.

Set up a mock for hash_sha3_256.

This is not available if the “crypto-primitives” feature is enabled. For more information on why, see the documentation of TestCryptoPrimitives.

Set up a mock for hash_keccak_256.

This is not available if the “crypto-primitives” feature is enabled. For more information on why, see the documentation of TestCryptoPrimitives.