pub struct TestCryptoPrimitives { /* private fields */ }Expand description
A HasCryptoPrimitives implementation used for unit testing smart
contracts.
You can test smart contracts that use the cryptographic primitives in two different ways:
- By setting up mock responses for the functions you need, for example with
the
setup_hash_sha_256_mockmethod. - Or, by using the actual implementations. For this, you need to enable the “crypto-primitives” feature.
Implementations
sourceimpl TestCryptoPrimitives
impl TestCryptoPrimitives
sourcepub fn new() -> Self
pub fn new() -> Self
Create a new TestCryptoPrimitives, for which no mocks has been set
up.
sourcepub fn setup_verify_ed25519_signature_mock<F>(&self, mock: F) where
F: FnMut(PublicKeyEd25519, SignatureEd25519, &[u8]) -> bool + 'static,
pub fn setup_verify_ed25519_signature_mock<F>(&self, mock: F) where
F: FnMut(PublicKeyEd25519, SignatureEd25519, &[u8]) -> bool + 'static,
Set up a mock for verify_ed25519_signature.
This is not available if the “crypto-primitives” feature is enabled. For
more information on why, see the documentation of
TestCryptoPrimitives.
sourcepub fn setup_verify_ecdsa_secp256k1_signature_mock<F>(&self, mock: F) where
F: FnMut(PublicKeyEcdsaSecp256k1, SignatureEcdsaSecp256k1, [u8; 32]) -> bool + 'static,
pub fn setup_verify_ecdsa_secp256k1_signature_mock<F>(&self, mock: F) where
F: FnMut(PublicKeyEcdsaSecp256k1, SignatureEcdsaSecp256k1, [u8; 32]) -> bool + 'static,
Set up a mock for verify_ecdsa_secp256k1_signature.
This is not available if the “crypto-primitives” feature is enabled. For
more information on why, see the documentation of
TestCryptoPrimitives.
sourcepub fn setup_hash_sha2_256_mock<F>(&self, mock: F) where
F: FnMut(&[u8]) -> HashSha2256 + 'static,
pub fn setup_hash_sha2_256_mock<F>(&self, mock: F) where
F: FnMut(&[u8]) -> HashSha2256 + 'static,
Set up a mock for
hash_sha2_256.
This is not available if the “crypto-primitives” feature is enabled. For
more information on why, see the documentation of
TestCryptoPrimitives.
sourcepub fn setup_hash_sha3_256_mock<F>(&self, mock: F) where
F: FnMut(&[u8]) -> HashSha3256 + 'static,
pub fn setup_hash_sha3_256_mock<F>(&self, mock: F) where
F: FnMut(&[u8]) -> HashSha3256 + 'static,
Set up a mock for
hash_sha3_256.
This is not available if the “crypto-primitives” feature is enabled. For
more information on why, see the documentation of
TestCryptoPrimitives.
sourcepub fn setup_hash_keccak_256_mock<F>(&self, mock: F) where
F: FnMut(&[u8]) -> HashKeccak256 + 'static,
pub fn setup_hash_keccak_256_mock<F>(&self, mock: F) where
F: FnMut(&[u8]) -> HashKeccak256 + 'static,
Set up a mock for
hash_keccak_256.
This is not available if the “crypto-primitives” feature is enabled. For
more information on why, see the documentation of
TestCryptoPrimitives.