Trait concordium_std::HasCommonData [−][src]
pub trait HasCommonData {
type PolicyType: HasPolicy;
type MetadataType: HasChainMetadata;
type ParamType: HasParameter + Read;
type PolicyIteratorType: ExactSizeIterator<Item = Self::PolicyType>;
fn policies(&self) -> Self::PolicyIteratorType;
fn metadata(&self) -> &Self::MetadataType;
fn parameter_cursor(&self) -> Self::ParamType;
}Expand description
Common data accessible to both init and receive methods.
Associated Types
type PolicyType: HasPolicy[src]
type MetadataType: HasChainMetadata[src]
type ParamType: HasParameter + Read[src]
type PolicyIteratorType: ExactSizeIterator<Item = Self::PolicyType>[src]
Required methods
fn policies(&self) -> Self::PolicyIteratorType[src]
Policies of the sender of the message. For init methods this is the would-be creator of the contract, for the receive this is the policies of the immediate sender.
In the latter case, if the sender is an account then it is the policies of the account, if it is a contract then it is the policies of the creator of the contract.
fn metadata(&self) -> &Self::MetadataType[src]
Get the reference to chain metadata
fn parameter_cursor(&self) -> Self::ParamType[src]
Get the cursor to the parameter.
Implementors
impl<'a, C> HasCommonData for ContextTest<'a, C>[src]
impl<'a, C> HasCommonData for ContextTest<'a, C>[src]