Trait concordium_std::HasReceiveContext [−][src]
Types which can act as receive contexts.
Associated Types
type ReceiveData[src]
Required methods
fn open(data: Self::ReceiveData) -> Self[src]
Open the receive context for reading and accessing values.
fn invoker(&self) -> AccountAddress[src]
Who is the account that initiated the top-level transaction this invocation is a part of.
fn self_address(&self) -> ContractAddress[src]
The address of the contract being invoked.
fn self_balance(&self) -> Amount[src]
Balance on the contract before the call was made.
fn sender(&self) -> Address[src]
The immediate sender of the message. In general different from the invoker.
fn owner(&self) -> AccountAddress[src]
Account which created the contract instance.